@@ -8,9 +8,9 @@
  * does it submit to any jurisdiction.
  */
 
+#include <iomanip>
 #include <iostream>
 #include <vector>
-#include <iomanip>
 
 #include "eckit/exception/Exceptions.h"
 #include "eckit/filesystem/URI.h"
@@ -86,8 +86,9 @@ bool URI::operator<(const URI& other) const {
 size_t URI::parseScheme(const std::string& uri) {
     std::size_t schemeEnd = uri.find(":");
     if (schemeEnd != std::string::npos) {
-        std::string schemeLowercase       = StringTools::lower(uri.substr(0, schemeEnd));
-        std::size_t acceptableProtocolEnd = schemeLowercase.find_first_not_of("abcdefghijklmnopqrstuvwxyz0123456789+-.");
+        std::string schemeLowercase = StringTools::lower(uri.substr(0, schemeEnd));
+        std::size_t acceptableProtocolEnd =
+            schemeLowercase.find_first_not_of("abcdefghijklmnopqrstuvwxyz0123456789+-.");
         if (acceptableProtocolEnd == std::string::npos) {
             scheme_ = schemeEnd == 0 ? "unix" : uri.substr(0, schemeEnd);
             return schemeEnd + 1;
@@ -219,7 +220,12 @@ std::string URI::authority() const {
 }
 
 void URI::query(const std::string& attribute, const std::string& value) {
-    queryValues_[attribute] = encode(value);
+    if (value.empty()) {
+        queryValues_.erase(attribute);
+    }
+    else {
+        queryValues_[attribute] = encode(value);
+    }
 }
 
 const std::string URI::query(const std::string& attribute) const {
@@ -264,13 +270,13 @@ std::string URI::encode(const std::string& value) {
 
     for (std::string::value_type c : value) {
         // Keep alphanumeric and other accepted characters intact
-        if (isalnum((unsigned char) c) || c == '-' || c == '_' || c == '.' || c == '~') {
+        if (isalnum((unsigned char)c) || c == '-' || c == '_' || c == '.' || c == '~') {
             escaped << c;
         }
         else {
             // Any other characters are percent-encoded
             escaped << std::uppercase;
-            escaped << '%' << std::setw(2) << int((unsigned char) c);
+            escaped << '%' << std::setw(2) << int((unsigned char)c);
             escaped << std::nouppercase;
         }
     }
@@ -281,13 +287,14 @@ std::string URI::encode(const std::string& value) {
 std::string URI::decode(const std::string& value) {
     std::string out;
 
-    for (int i=0; i<value.length(); i++) {
-        if (value[i]=='%') {
-            unsigned int x = std::stoul(value.substr(i+1,2), nullptr, 16);
-            out+=static_cast<char>(x);
-            i+=2;
-        } else {
-            out+=value[i];
+    for (int i = 0; i < value.length(); i++) {
+        if (value[i] == '%') {
+            unsigned int x = std::stoul(value.substr(i + 1, 2), nullptr, 16);
+            out += static_cast<char>(x);
+            i += 2;
+        }
+        else {
+            out += value[i];
         }
     }
 
@@ -295,7 +302,6 @@ std::string URI::decode(const std::string& value) {
 }
 
 
-
 std::string URI::asRawString() const {
     std::string auth = authority();
     if (!auth.empty()) {
