@@ -15,16 +15,16 @@
 #include <iosfwd>
 #include <variant>
 
-#include "eckit/geo/Point2.h"
-#include "eckit/geo/Point3.h"
 #include "eckit/geo/PointLonLat.h"
 #include "eckit/geo/PointLonLatR.h"
+#include "eckit/geo/PointXY.h"
+#include "eckit/geo/PointXYZ.h"
 
 
 namespace eckit::geo {
 
 
-using Point = std::variant<std::monostate, Point2, Point3, PointLonLat, PointLonLatR>;
+using Point = std::variant<std::monostate, PointXY, PointXYZ, PointLonLat, PointLonLatR>;
 
 bool points_equal(const Point&, const Point&);
 bool points_equal(const Point&, const Point&, double eps);
