@@ -14,7 +14,7 @@
 
 #include <cmath>
 
-#include "eckit/exception/Exceptions.h"
+#include "eckit/geo/Exceptions.h"
 #include "eckit/geo/spec/Custom.h"
 #include "eckit/geo/util.h"
 #include "eckit/types/FloatCompare.h"
@@ -23,12 +23,12 @@
 namespace eckit::geo::projection {
 
 
-static ProjectionBuilder<Stretch> PROJECTION("stretch");
+static ProjectionRegisterType<Stretch> PROJECTION("stretch");
 
 
 Stretch::Stretch(double c) : c_(c) {
     if (types::is_approximately_equal(c_, 0.)) {
-        throw ProjectionProblem("Stretch: stretching_factor != 0", Here());
+        throw exception::ProjectionError("Stretch: stretching_factor != 0", Here());
     }
     ASSERT(c_ != 0.);
 }
@@ -37,6 +37,12 @@ Stretch::Stretch(double c) : c_(c) {
 Stretch::Stretch(const Spec& spec) : Stretch(spec.get_double("stretching_factor")) {}
 
 
+const std::string& Stretch::type() const {
+    static const std::string type{"stretch"};
+    return type;
+}
+
+
 double Stretch::stretch(double a, double c) {
     auto ar = util::DEGREE_TO_RADIAN * a;
     ar      = std::asin(std::cos(2. * std::atan(c * std::tan(std::acos(std::sin(ar)) * 0.5))));
@@ -45,7 +51,7 @@ double Stretch::stretch(double a, double c) {
 
 
 void Stretch::fill_spec(spec::Custom& spec) const {
-    spec.set("projection", "stretch");
+    spec.set("type", "stretch");
     spec.set("stretching_factor", c_);
 }
 
