@@ -16,17 +16,14 @@
 #include "eckit/io/Buffer.h"
 #include "eckit/serialisation/Stream.h"
 
-namespace eckit {
-namespace linalg {
+namespace eckit::linalg {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-Matrix::Matrix() :
-    array_(0), rows_(0), cols_(0), own_(false) {}
+Matrix::Matrix() : array_(0), rows_(0), cols_(0), own_(false) {}
 
 
-Matrix::Matrix(Size rows, Size cols) :
-    array_(new Scalar[rows * cols]), rows_(rows), cols_(cols), own_(true) {
+Matrix::Matrix(Size rows, Size cols) : array_(new Scalar[rows * cols]), rows_(rows), cols_(cols), own_(true) {
     ASSERT(size() > 0);
     ASSERT(array_);
 }
@@ -39,8 +36,7 @@ Matrix::Matrix(const Scalar* array, Size rows, Size cols) :
 }
 
 
-Matrix::Matrix(Stream& stream) :
-    array_(0), rows_(0), cols_(0), own_(false) {
+Matrix::Matrix(Stream& stream) : array_(0), rows_(0), cols_(0), own_(false) {
     Size rows, cols;
     stream >> rows;
     stream >> cols;
@@ -123,5 +119,4 @@ Stream& operator<<(Stream& stream, const Matrix& matrix) {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-}  // namespace linalg
-}  // namespace eckit
+}  // namespace eckit::linalg
