@@ -20,16 +20,19 @@ namespace eckit {
 
 class BadConversion : public Exception {
 public:
+
     BadConversion(const std::string& w, const CodeLocation& loc);
 };
 
 class BadComparison : public Exception {
 public:
+
     BadComparison(const std::string& w, const CodeLocation& loc);
 };
 
 class BadOperator : public Exception {
 public:
+
     BadOperator(const std::string& w, const CodeLocation& loc);
 };
 
@@ -64,8 +67,7 @@ void Content::encode(Stream& s) const {
     Streamable::encode(s);
 }
 
-Content::Content(Stream& s) :
-    Streamable(s) {}
+Content::Content(Stream& s) : Streamable(s) {}
 
 Content::~Content() {}
 
